@@ -3,12 +3,12 @@ use Encode::Locale;
 sub Mojo::Webqq::Client::_get_img_verify_code{
     my $self = shift;
     return 1 if $self->login_type ne "login";
-    #return 1 if not $self->is_need_img_verifycode ;
+    return 1 if not $self->is_need_img_verifycode ;
     $self->verifycode(undef);
     my $api_url = 'https://ssl.captcha.qq.com/getimage';
     my $headers ={Referer => 'https://ui.ptlogin2.qq.com/cgi-bin/login?daid=164&target=self&style=16&mibao_css=m_webqq&appid=501004106&enable_qlogin=0&no_verifyimg=1&s_url=http%3A%2F%2Fw.qq.com%2Fproxy.html&f_url=loginerroralert&strong_login=1&login_state=10&t=20131024001'};
     my @query_string = (
-        aid        => $self->g_appid,
+        aid        => 501004106,
         r          => rand(),
         uin        => $self->uid, 
         cap_cd     => $self->cap_cd,
